/* *********** NOTE ************
 * modified by S. Dreher 2006
 *
 * This Class is more than highly inspired by the GMail notifier extension
 * Preferences class by Doron Rosenberg. It is used here under the terms of the
 * GPL in compliance with the License included in the original Source.
 *
 ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Home Status Notifier code.
 *
 * The Initial Developer of the Original Code is S. Dreher (Zapp)
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
function hc_preferences(){
  //dump("hc-preferences.js -> Constructor");
  this.prefBranch = null;

  // pref values
  this.PREF_RSS_URL				  = "homecontrol.rss.url"; 
  this.PREF_UPDATE_INTERVAL       = "homecontrol.update.interval";
  this.PREF_BLOWFISH_KEY		  = "homecontrol.connection.blowfish.key";
  this.PREF_ENCRYPTED_XML  		  = "homecontrol.connection.use.encrypted.xml";
  this.PREF_SHORTCUT_URL		  = "homecontrol.shortcut.url";
  this.PREF_MODULES_TO_SHOW		  = "homecontrol.modules.to.show";
  this.PREF_NOTIFICATIONS_ENABLED = "homecontrol.ui.notification.enabled";
  this.PREF_SOUNDNOTIFICATIONS_ENABLED = "homecontrol.ui.soundnotification.enabled";
  this.PREF_SOUNDNOTIFICATIONS_URI = "homecontrol.ui.soundnotification.uri";
  this.PREF_COUNTER_SHOW_CALLS    = "homecontrol.ui.counter.showInbox";
  this.PREF_DEFAULT_USER          = "homecontrol.users.default";
  this.PREF_REMEMBER_PASSWORD     = "homecontrol.users.remember-password";
}

hc_preferences.prototype.getPrefBranch = function(){
  //alert("hc-preferences.js -> Getting Pref Branch from Mozilla Services");
  if (!this.prefBranch){ 
    this.prefBranch = Components.classes['@mozilla.org/preferences-service;1'].getService();
    this.prefBranch = this.prefBranch.QueryInterface(Components.interfaces.nsIPrefBranch);
  }

  return this.prefBranch;
}

hc_preferences.prototype.setBoolPref = function(aName, aValue){
  this.getPrefBranch().setBoolPref(aName, aValue);
}

hc_preferences.prototype.getBoolPref = function(aName){
  var rv = null;

  try{
    rv = this.getPrefBranch().getBoolPref(aName);
  } catch (e) {}

  return rv;
}

hc_preferences.prototype.setIntPref = function(aName, aValue){
  this.getPrefBranch().setIntPref(aName, aValue);
}

hc_preferences.prototype.getIntPref = function(aName){
  //alert("hc-preferences.js -> getIntPref(" + aName + ")");
  var rv = null;

  try{
    rv = this.getPrefBranch().getIntPref(aName);
  } catch (e){
  }

  return rv;
}

hc_preferences.prototype.setCharPref = function(aName, aValue) {
  this.getPrefBranch().setCharPref(aName, aValue);
}

hc_preferences.prototype.getCharPref = function(aName) {
  var rv = null;

  try{
    rv = this.getPrefBranch().getCharPref(aName);
  } catch (e){

  }
  //alert("hc-preferences.js -> Got Char Pref for " + aName + " -> " + rv);

  return rv;
}

hc_preferences.prototype.addObserver = function(aDomain, aFunction) {
  //alert("hc-preferences.js -> Add an Observer");
  var myPrefs = this.getPrefBranch();
  var prefBranchInternal = myPrefs.QueryInterface(Components.interfaces.nsIPrefBranchInternal);

  if (prefBranchInternal)
    prefBranchInternal.addObserver(aDomain, aFunction, false);
}

hc_preferences.prototype.removeObserver = function(aDomain, aFunction) {
  var myPrefs = this.getPrefBranch();
  var prefBranchInternal = myPrefs.QueryInterface(Components.interfaces.nsIPrefBranchInternal);

  if (prefBranchInternal)
    prefBranchInternal.removeObserver(aDomain, aFunction);
}

hc_preferences.prototype.initPrefs = function() {
  //dump("hc-preferences.js -> Initializing Preferences");
  // migrate preferences
  //var arePrefsUpToDate = this.getBoolPref(this.PREF_ENCRYPTED_XML);
  var arePrefsUpToDate = this.getCharPref(this.PREF_RSS_URL);
  if (arePrefsUpToDate == null){
    // set prefs if they don't exit
    this.initPref(this.PREF_RSS_URL, "char", "");
    this.initPref(this.PREF_UPDATE_INTERVAL, "int", 10);
    this.initPref(this.PREF_BLOWFISH_KEY, "char", "");
    this.initPref(this.PREF_ENCRYPTED_XML, "bool", false);
    this.initPref(this.PREF_SHORTCUT_URL, "char", "");
    this.initPref(this.PREF_NOTIFICATIONS_ENABLED, "bool", true);
    this.initPref(this.PREF_SOUNDNOTIFICATIONS_ENABLED, "bool", false);
    this.initPref(this.PREF_COUNTER_SHOW_CALLS, "bool", true);
    this.initPref(this.PREF_DEFAULT_USER, "char", "");
    this.initPref(this.PREF_REMEMBER_PASSWORD, "bool", false);
  }
  var areModulesUpToDate = this.getIntPref(this.PREF_MODULES_TO_SHOW);
  // Set Modules To Show if it has not been defined
  if (areModulesUpToDate == null)
      this.initPref(this.PREF_MODULES_TO_SHOW, "int", 1023);
}

hc_preferences.prototype.initPref = function(aPrefName, aPrefType, aDefaultValue) {
  //alert("hc-preferences.js -> Initializing Pref " + aPrefName + " to " + aDefaultValue);
  switch (aPrefType) {
    case "bool" :
      var prefExists = this.getBoolPref(aPrefName);
      if (prefExists == null)
        this.setBoolPref(aPrefName, aDefaultValue);
      break;

    case "int" :
      var prefExists = this.getIntPref(aPrefName);
      if (prefExists == null)
        this.setIntPref(aPrefName, aDefaultValue);
      break;

    case "char" :
      var prefExists = this.getCharPref(aPrefName);
      if (prefExists == null)
        this.setCharPref(aPrefName, aDefaultValue);
      break;
  }
}

